FontJobResult class
Result of runFontJob.
Constructors
- FontJobResult({String? name, required SvgToOtfResult otf, String? classSource})
-
const
Properties
- classSource → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String?
-
final
- otf → SvgToOtfResult
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited